@@ -1,9 +1,26 @@
+import time
+
 from datetime import datetime
 
 GITHUB_TIMEZONE = "-0700"
 GITHUB_DATE_FORMAT = "%Y/%m/%d %H:%M:%S"
 #2009-03-21T18:01:48-07:00
 COMMIT_DATE_FORMAT = "%Y-%m-%dT%H:%M:%S"
+COMMIT_TIMEZONE = "-07:00"
+
+
+def strptime(string, format):
+    """Parse date strings according to specified format
+
+    We have to create our :obj:`~datetime.datetime` objects indirectly to remain
+    compatible with Python 2.4, where the :class:`~datetime.datetime` class has
+    no :meth:`~datetime.datetime.strptime` method.
+
+    :param str string: String to parse
+    :param str format: Datetime format
+    :return datetime: Parsed datetime
+    """
+    return datetime(*(time.strptime(string, format)[:6]))
 
 
 def ghdate_to_datetime(github_date):
@@ -12,13 +29,13 @@ def ghdate_to_datetime(github_date):
     :param str github_date: date string to parse
     """
     date_without_tz = " ".join(github_date.strip().split()[:2])
-    return datetime.strptime(date_without_tz, GITHUB_DATE_FORMAT)
+    return strptime(date_without_tz, GITHUB_DATE_FORMAT)
 
 
 def datetime_to_ghdate(datetime_):
     """Convert Python datetime to Github date string
 
-    :param str datetime_: datetime object to convert
+    :param datetime datetime_: datetime object to convert
     """
     date_without_tz = datetime_.strftime(GITHUB_DATE_FORMAT)
     return " ".join([date_without_tz, GITHUB_TIMEZONE])
@@ -30,16 +47,31 @@ def commitdate_to_datetime(commit_date):
     :param str github_date: date string to parse
     """
     date_without_tz = commit_date[:-6]
-    return datetime.strptime(date_without_tz, COMMIT_DATE_FORMAT)
+    return strptime(date_without_tz, COMMIT_DATE_FORMAT)
 
 
 def datetime_to_commitdate(datetime_):
     """Convert Python datetime to Github date string
 
-    :param str datetime_: datetime object to convert
+    :param datetime datetime_: datetime object to convert
     """
     date_without_tz = datetime_.strftime(COMMIT_DATE_FORMAT)
-    return "".join([date_without_tz, GITHUB_TIMEZONE])
+    return "".join([date_without_tz, COMMIT_TIMEZONE])
+
+
+def userdate_to_datetime(user_date):
+    """Convert user date string to Python datetime
+
+    Unfortunately this needs a special case because :meth:`~Github.users.show`
+    and :meth:`~Github.users.search` return a different formats for the
+    `created_at` attributes.
+
+    :param str user_date: date string to parse
+    """
+    try:
+        return ghdate_to_datetime(user_date)
+    except ValueError:
+        return strptime(user_date, '%Y-%m-%dT%H:%M:%SZ')
 
 
 class GithubCommand(object):
@@ -51,9 +83,15 @@ class GithubCommand(object):
         filter = kwargs.get("filter")
         post_data = kwargs.get("post_data") or {}
         method = kwargs.get("method", "GET")
-        if post_data or method.upper() == "POST":
+        if method.upper() in ("POST", "GET") and post_data:
             response = self.request.post(self.domain, command, *args,
                                          **post_data)
+        elif method.upper() == "PUT":
+            response = self.request.put(self.domain, command, *args,
+                                        **post_data)
+        elif method.upper() == "DELETE":
+            response = self.request.delete(self.domain, command, *args,
+                                           **post_data)
         else:
             response = self.request.get(self.domain, command, *args)
         if filter:
@@ -91,7 +129,7 @@ def doc_generator(docstring, attributes):
     docstring = docstring or ""
 
     def bullet(title, text):
-        return """.. py:attribute:: %s\n\n   %s\n""" % (title, text)
+        return """.. attribute:: %s\n\n   %s\n""" % (title, text)
 
     b = "\n".join([bullet(attr_name, attr.help)
                    for attr_name, attr in attributes.items()])
@@ -120,6 +158,10 @@ class DateAttribute(Attribute):
             "to": commitdate_to_datetime,
             "from": datetime_to_commitdate,
         },
+        "user": {
+            "to" : userdate_to_datetime,
+            "from": datetime_to_ghdate,
+        }
     }
 
     def __init__(self, *args, **kwargs):
