@@ -1,4 +1,5 @@
 import datetime
+import re
 import sys
 import time
 import httplib2
@@ -6,6 +7,10 @@ try:
     import json as simplejson  # For Python 2.6
 except ImportError:
     import simplejson
+try:
+    import socks  # SOCKS support may not be installed
+except ImportError:
+    socks = None
 from urlparse import (urlsplit, urlunsplit)
 try:
     from urlparse import parse_qs
@@ -18,6 +23,20 @@ from urllib import urlencode, quote
 GITHUB_URL = "https://github.com"
 
 
+def charset_from_headers(headers):
+    """Parse charset from headers
+
+    :param httplib2.Response headers: Request headers
+    :return: Defined encoding, or default to ASCII
+    """
+    match = re.search("charset=([^ ;]+)", headers.get('content-type', ""))
+    if match:
+        charset = match.groups()[0]
+    else:
+        charset = "ascii"
+    return charset
+
+
 class GithubError(Exception):
     """An error occured when making a request to the Github API."""
 
@@ -31,10 +50,10 @@ class GithubRequest(object):
 
     def __init__(self, username=None, api_token=None, url_prefix=None,
             debug=False, requests_per_second=None, access_token=None,
-            cache=None):
+            cache=None, proxy_host=None, proxy_port=None):
         """Make an API request.
 
-        :see: :py:class:`github2.client.Github`
+        :see: :class:`github2.client.Github`
         """
         self.username = username
         self.api_token = api_token
@@ -52,7 +71,15 @@ class GithubRequest(object):
                 "api_version": self.api_version,
                 "api_format": self.api_format,
             }
-        self._http = httplib2.Http(cache=cache)
+        if proxy_host is None:
+            self._http = httplib2.Http(cache=cache)
+        elif proxy_host and socks is None:
+            raise GithubError('Proxy support missing.  '
+                              'Install a Python SOCKS library.')
+        else:
+            proxy_info = httplib2.ProxyInfo(socks.PROXY_TYPE_HTTP,
+                                            proxy_host, proxy_port),
+            self._http = httplib2.Http(proxy_info=proxy_info, cache=cache)
 
     def encode_authentication_data(self, extra_post_data):
         if self.access_token:
@@ -74,6 +101,16 @@ class GithubRequest(object):
         return self.make_request("/".join(path_components), extra_post_data,
             method="POST")
 
+    def put(self, *path_components, **extra_post_data):
+        path_components = filter(None, path_components)
+        return self.make_request("/".join(path_components), extra_post_data,
+            method="PUT")
+
+    def delete(self, *path_components, **extra_post_data):
+        path_components = filter(None, path_components)
+        return self.make_request("/".join(path_components), extra_post_data,
+            method="DELETE")
+
     def make_request(self, path, extra_post_data=None, method="GET"):
         if self.delay:
             since_last = (datetime.datetime.now() - self.last_request)
@@ -111,7 +148,7 @@ class GithubRequest(object):
         if response.status >= 400:
             raise RuntimeError("unexpected response from github.com %d: %r" % (
                                response.status, content))
-        json = simplejson.loads(content)
+        json = simplejson.loads(content.decode(charset_from_headers(response)))
         if json.get("error"):
             raise self.GithubError(json["error"][0]["error"])
 
